From 7c2f7617598d96873dc44c898a12e1e808646975 Mon Sep 17 00:00:00 2001
From: Olivier Martin <olivier.martin@arm.com>
Date: Mon, 21 Oct 2013 17:18:36 +0100
Subject: [PATCH 01/14] ArmPkg/Drivers/ArmGic: Introduced
 ArmGicEndOfInterrupt()

Change-Id: I17b58e4fe6062a9c5adb493b87d6e9185eabc393
---
 ArmPkg/Drivers/ArmGic/ArmGic.c     | 13 ++++++++++++-
 ArmPkg/Drivers/ArmGic/ArmGicDxe.c  |  2 +-
 ArmPkg/Drivers/ArmGic/ArmGicSec.c  |  2 +-
 ArmPkg/Include/Library/ArmGicLib.h |  7 +++++++
 4 files changed, 21 insertions(+), 3 deletions(-)

diff --git a/ArmPkg/Drivers/ArmGic/ArmGic.c b/ArmPkg/Drivers/ArmGic/ArmGic.c
index 8a10d11..86bbb1d 100644
--- a/ArmPkg/Drivers/ArmGic/ArmGic.c
+++ b/ArmPkg/Drivers/ArmGic/ArmGic.c
@@ -55,7 +55,7 @@ ArmGicAcknowledgeInterrupt (
   // Check if it is a valid interrupt ID
   if ((Interrupt & 0x3FF) < ArmGicGetMaxNumInterrupts (GicDistributorBase)) {
     // Got a valid SGI number hence signal End of Interrupt by writing to ICCEOIR
-    MmioWrite32 (GicInterruptInterfaceBase + ARM_GIC_ICCEIOR, Interrupt);
+    ArmGicEndOfInterrupt (GicInterruptInterfaceBase, Interrupt);
 
     if (CoreId) {
       *CoreId = (Interrupt >> 10) & 0x7;
@@ -68,3 +68,14 @@ ArmGicAcknowledgeInterrupt (
     return RETURN_INVALID_PARAMETER;
   }
 }
+
+RETURN_STATUS
+EFIAPI
+ArmGicEndOfInterrupt (
+  IN  UINTN                 GicInterruptInterfaceBase,
+  IN UINTN                  Source
+  )
+{
+  MmioWrite32 (GicInterruptInterfaceBase + ARM_GIC_ICCEIOR, Source);
+  return RETURN_SUCCESS;
+}
diff --git a/ArmPkg/Drivers/ArmGic/ArmGicDxe.c b/ArmPkg/Drivers/ArmGic/ArmGicDxe.c
index 111ce14..e227f19 100644
--- a/ArmPkg/Drivers/ArmGic/ArmGicDxe.c
+++ b/ArmPkg/Drivers/ArmGic/ArmGicDxe.c
@@ -227,7 +227,7 @@ EndOfInterrupt (
     return EFI_UNSUPPORTED;
   }
 
-  MmioWrite32 (PcdGet32(PcdGicInterruptInterfaceBase) + ARM_GIC_ICCEIOR, Source);
+  ArmGicEndOfInterrupt (PcdGet32(PcdGicInterruptInterfaceBase), Source);
   return EFI_SUCCESS;
 }
 
diff --git a/ArmPkg/Drivers/ArmGic/ArmGicSec.c b/ArmPkg/Drivers/ArmGic/ArmGicSec.c
index bae76e4..f249eac 100644
--- a/ArmPkg/Drivers/ArmGic/ArmGicSec.c
+++ b/ArmPkg/Drivers/ArmGic/ArmGicSec.c
@@ -45,7 +45,7 @@ ArmGicSetupNonSecure (
   // Only try to clear valid interrupts. Ignore spurious interrupts.
   while ((InterruptId & 0x3FF) < ArmGicGetMaxNumInterrupts (GicDistributorBase))   {
     // Some of the SGI's are still pending, read Ack register and send End of Interrupt Signal
-    MmioWrite32 (GicInterruptInterfaceBase + ARM_GIC_ICCEIOR, InterruptId);
+    ArmGicEndOfInterrupt (GicInterruptInterfaceBase, InterruptId);
 
     // Next
     InterruptId = MmioRead32 (GicInterruptInterfaceBase + ARM_GIC_ICCIAR);
diff --git a/ArmPkg/Include/Library/ArmGicLib.h b/ArmPkg/Include/Library/ArmGicLib.h
index 3280cf8..75c1c1f 100644
--- a/ArmPkg/Include/Library/ArmGicLib.h
+++ b/ArmPkg/Include/Library/ArmGicLib.h
@@ -137,6 +137,13 @@ ArmGicAcknowledgeInterrupt (
   OUT UINTN          *InterruptId
   );
 
+RETURN_STATUS
+EFIAPI
+ArmGicEndOfInterrupt (
+  IN  UINTN                 GicInterruptInterfaceBase,
+  IN UINTN                  Source
+  );
+
 UINTN
 EFIAPI
 ArmGicSetPriorityMask (
-- 
1.8.5

